# Changelog

## 0.1.0-rc1

### Features
This initial RC release exposes the following functions to Python:
	- compile
	- rewrite_arithmentic
	- translate
	- submit
	- retrieve_results
	- build_patch_values

As this is a release candidate, they can be used experimentally to get a preview of upcoming functionality. Please report any issues and expect that these signatures and workflows are going to be changed before a full release.
